SEORenderMode enum

Controls which output format(s) SEOHtml.toHtmlString produces.

Inheritance
Available extensions

Values

htmlOnly → const SEORenderMode

Clean HTML — no schema attributes, no JSON-LD script tags.

microdata → const SEORenderMode

HTML with microdata attributes derived from SEOHtml.jsonLd.

jsonLdOnly → const SEORenderMode

Only JSON-LD <script> tags, no body HTML.

full → const SEORenderMode

Clean HTML + JSON-LD script tags.

microdataAndJsonLd → const SEORenderMode

HTML with microdata attributes + JSON-LD script tags.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<SEORenderMode>
A constant List of the values in this enum, in order of their declaration.