SEOUnorderedList class

Inheritance
Available extensions

Constructors

SEOUnorderedList({String? content, Map<String, String>? attributes, List<SEOHtml> children = const [], Map<String, dynamic>? jsonLd})
const

Properties

attributes Map<String, String>?
finalinherited
children List<SEOHtml>
finalinherited
content String?
finalinherited
hashCode int
The hash code for this object.
no setterinherited
jsonLd Map<String, dynamic>?
finalinherited
relativePath String?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tag String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve(BuildContext context) SEOHtml
inherited
toHtmlString({int indentLevel = 0, SEORenderMode mode = SEORenderMode.microdataAndJsonLd}) String
inherited
toJsonLd() List<Map<String, dynamic>>
Walks the tree and returns JSON-LD blocks. Children with itemprop + jsonLd nest into the parent block. Children with jsonLd but no itemprop become independent blocks. Children with itemprop but no jsonLd extract value from attrs/content.
inherited
toMarkdown() String
Converts this SEOHtml tree into CommonMark Markdown.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited