SeoSuccess class

The "Success" state containing the complex data you previously had in your typedef.

Inheritance

Constructors

SeoSuccess({required String fullHtml, required String currentLanguage, required String path, required String headContent, required String bodyContent})
const

Properties

bodyContent String
final
currentLanguage String
final
fullHtml String
final
hashCode int
The hash code for this object.
no setterinherited
headContent String
final
path String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited