menu
flutter_easy_seo package
documentation
flutter_easy_seo.dart
SEOUnorderedList class
SEOUnorderedList class
dark_mode
light_mode
SEOUnorderedList
class
Inheritance
Object
SEOHtml
SEOUnorderedList
Available extensions
SEOHtmlJsonLd
Constructors
SEOUnorderedList
({
String
?
content
,
Map
<
String
,
String
>
?
attributes
,
List
<
SEOHtml
>
children
=
const []
,
Map
<
String
,
dynamic
>
?
jsonLd
})
const
Properties
attributes
→
Map
<
String
,
String
>
?
final
inherited
children
→
List
<
SEOHtml
>
final
inherited
content
→
String
?
final
inherited
hashCode
→
int
The hash code for this object.
no setter
inherited
jsonLd
→
Map
<
String
,
dynamic
>
?
final
inherited
relativePath
→
String
?
final
inherited
runtimeType
→
Type
A representation of the runtime type of the object.
no setter
inherited
tag
→
String
final
inherited
Methods
noSuchMethod
(
Invocation
invocation
)
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve
(
BuildContext
context
)
→
SEOHtml
inherited
toHtmlString
(
{
int
indentLevel
=
0
,
SEORenderMode
mode
=
SEORenderMode.microdataAndJsonLd
})
→
String
inherited
toJsonLd
(
)
→
List
<
Map
<
String
,
dynamic
>
>
Walks the tree and returns JSON-LD blocks. Children with
itemprop
+
jsonLd
nest into the parent block. Children with
jsonLd
but no
itemprop
become independent blocks. Children with
itemprop
but no
jsonLd
extract value from attrs/content.
inherited
toMarkdown
(
)
→
String
Converts this
SEOHtml
tree into CommonMark Markdown.
inherited
toString
(
)
→
String
A string representation of this object.
inherited
Operators
operator ==
(
Object
other
)
→
bool
The equality operator.
inherited
flutter_easy_seo package
documentation
flutter_easy_seo
SEOUnorderedList class
flutter_easy_seo library