URLHelper class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- rawCurrentPath → String
-
Platform-specific implementation to get the raw path
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getCurrentPath(
) → String -
Returns the current path (pathname).
inherited
-
isPathMatch(
String urlPath, String pattern) → bool -
Checks if a given
urlPathmatches apattern(e.g., 'compare/:productId').inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited